bl_info = {
    "name": "Scene and ViewLayer Switcher",
    "author": "1P2D (Felix Pierron)",
    "version": (1, 0, 0),
    "blender": (4, 2, 0),
    "location": "Everywhere",
    "description": "Jump to the next/previous Scene or ViewLayer",
    "warning": "",
    "doc_url": "1P2D.com",
    "category": "User Interface"
}

import bpy
from . import operators, preferences

# We'll store the addon keymaps here
addon_keymaps = []

def register():
    operators.register()
    preferences.register()
    register_keymaps()

def unregister():
    unregister_keymaps()
    preferences.unregister()
    operators.unregister()

def register_keymaps():
    global addon_keymaps
    wm = bpy.context.window_manager
    kc = wm.keyconfigs.addon
    if kc:
        # Next Scene Keymap
        km = kc.keymaps.new(name='Window', space_type='EMPTY')
        kmi = km.keymap_items.new('scene_switcher.next_scene', 'PAGE_DOWN', 'PRESS')
        kmi.active = True
        addon_keymaps.append((km, kmi))

        # Previous Scene Keymap
        kmi_prev = km.keymap_items.new('scene_switcher.previous_scene', 'PAGE_UP', 'PRESS')
        kmi_prev.active = True
        addon_keymaps.append((km, kmi_prev))

        # Next View Layer Keymap
        kmi_next_vl = km.keymap_items.new('scene_switcher.next_view_layer', 'PAGE_DOWN', 'PRESS', alt=True)
        kmi_next_vl.active = True
        addon_keymaps.append((km, kmi_next_vl))

        # Previous View Layer Keymap
        kmi_prev_vl = km.keymap_items.new('scene_switcher.previous_view_layer', 'PAGE_UP', 'PRESS', alt=True)
        kmi_prev_vl.active = True
        addon_keymaps.append((km, kmi_prev_vl))

def unregister_keymaps():
    global addon_keymaps
    wm = bpy.context.window_manager
    kc = wm.keyconfigs.addon
    if kc:
        for km, kmi in addon_keymaps:
            km.keymap_items.remove(kmi)
    addon_keymaps.clear()

if __name__ == "__main__":
    register()
