import bpy
from bpy.types import Operator
from bpy.utils import register_class, unregister_class

def switch_to_next_scene(context):
    current_scene = context.scene
    scenes = bpy.data.scenes
    scene_names = [scene.name for scene in scenes]
    current_index = scene_names.index(current_scene.name)
    next_index = (current_index + 1) % len(scenes)
    next_scene = scenes[next_index]
    context.window.scene = next_scene

def switch_to_previous_scene(context):
    current_scene = context.scene
    scenes = bpy.data.scenes
    scene_names = [scene.name for scene in scenes]
    current_index = scene_names.index(current_scene.name)
    previous_index = (current_index - 1) % len(scenes)
    previous_scene = scenes[previous_index]
    context.window.scene = previous_scene

def switch_to_next_view_layer(context):
    current_view_layer = context.view_layer
    view_layers = context.scene.view_layers
    vl_names = [vl.name for vl in view_layers]
    current_index = vl_names.index(current_view_layer.name)
    next_index = (current_index + 1) % len(view_layers)
    next_view_layer = view_layers[next_index]
    context.window.view_layer = next_view_layer

def switch_to_previous_view_layer(context):
    current_view_layer = context.view_layer
    view_layers = context.scene.view_layers
    vl_names = [vl.name for vl in view_layers]
    current_index = vl_names.index(current_view_layer.name)
    previous_index = (current_index - 1) % len(view_layers)
    previous_view_layer = view_layers[previous_index]
    context.window.view_layer = previous_view_layer

class SCENE_SWITCHER_OT_next_scene(Operator):
    """Switch to the next scene"""
    bl_idname = "scene_switcher.next_scene"
    bl_label = "Next Scene"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        switch_to_next_scene(context)
        return {'FINISHED'}

class SCENE_SWITCHER_OT_previous_scene(Operator):
    """Switch to the previous scene"""
    bl_idname = "scene_switcher.previous_scene"
    bl_label = "Previous Scene"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        switch_to_previous_scene(context)
        return {'FINISHED'}

class SCENE_SWITCHER_OT_next_view_layer(Operator):
    """Switch to the next view layer"""
    bl_idname = "scene_switcher.next_view_layer"
    bl_label = "Next View Layer"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        switch_to_next_view_layer(context)
        return {'FINISHED'}

class SCENE_SWITCHER_OT_previous_view_layer(Operator):
    """Switch to the previous view layer"""
    bl_idname = "scene_switcher.previous_view_layer"
    bl_label = "Previous View Layer"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        switch_to_previous_view_layer(context)
        return {'FINISHED'}

classes = (
    SCENE_SWITCHER_OT_next_scene,
    SCENE_SWITCHER_OT_previous_scene,
    SCENE_SWITCHER_OT_next_view_layer,
    SCENE_SWITCHER_OT_previous_view_layer,
)

def register():
    for cls in classes:
        register_class(cls)

def unregister():
    for cls in reversed(classes):
        unregister_class(cls)
