import bpy
import rna_keymap_ui

class SceneSwitcherPreferences(bpy.types.AddonPreferences):
    bl_idname = __package__

    def draw(self, context):
        layout = self.layout
        self.draw_keymaps(context, layout)

    def draw_keymaps(self, context, layout):
        wm = context.window_manager
        kc = wm.keyconfigs.user

        keymaps_info = [
            {
                'km_name': 'Window',
                'space_type': 'EMPTY',
                'region_type': 'WINDOW',
                'operator_idname': 'scene_switcher.next_scene',
            },
            {
                'km_name': 'Window',
                'space_type': 'EMPTY',
                'region_type': 'WINDOW',
                'operator_idname': 'scene_switcher.previous_scene',
            },
            {
                'km_name': 'Window',
                'space_type': 'EMPTY',
                'region_type': 'WINDOW',
                'operator_idname': 'scene_switcher.next_view_layer',
            },
            {
                'km_name': 'Window',
                'space_type': 'EMPTY',
                'region_type': 'WINDOW',
                'operator_idname': 'scene_switcher.previous_view_layer',
            },
        ]

        # Create a column layout with alignment
        col = layout.column(align=True)
        for km_info in keymaps_info:
            km = kc.keymaps.get(km_info['km_name'])
            if not km:
                continue

            for kmi in km.keymap_items:
                if kmi.idname == km_info['operator_idname']:
                    # Draw the keymap item without labels and minimize spacing
                    rna_keymap_ui.draw_kmi([], kc, km, kmi, col, 0)
                    break

def register():
    bpy.utils.register_class(SceneSwitcherPreferences)

def unregister():
    bpy.utils.unregister_class(SceneSwitcherPreferences)
